#
# spec file for package python-tox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%if %{defined sle15_python_module_pythons}
%bcond_without devpi_process
%else
%bcond_with devpi_process
%endif
Name:           python-tox
Version:        4.14.2
Release:        3.1
Summary:        Virtualenv-based automation of test activities
License:        MIT
URL:            https://github.com/tox-dev/tox
Source:         https://files.pythonhosted.org/packages/source/t/tox/tox-%{version}.tar.gz
# PATCH-FIX-OPENSUSE optional_devpi_process.patch mcepl@suse.com
# Make use devpi_process optional
Patch0:         optional_devpi_process.patch
# PATCH-FEATURE-UPSTREAM mark-network-tests.patch mcepl@suse.com
# to skip test which require network access
Patch1:         mark-network-tests.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module build >= 0.10.0}
BuildRequires:  %{python_module cachetools >= 5.3.2}
BuildRequires:  %{python_module chardet >= 5.2}
BuildRequires:  %{python_module colorama >= 0.4.6}
BuildRequires:  %{python_module filelock >= 3.13.1}
BuildRequires:  %{python_module hatch >= 0.3}
BuildRequires:  %{python_module hatch_vcs >= 0.4}
BuildRequires:  %{python_module hatchling >= 1.21}
BuildRequires:  %{python_module packaging >= 23.2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module platformdirs >= 4.1}
BuildRequires:  %{python_module pluggy >= 1.3}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pyproject-api >= 1.6.1}
BuildRequires:  %{python_module pytoml >= 0.1}
BuildRequires:  %{python_module re-assert}
BuildRequires:  %{python_module setuptools >= 41.0.1}
BuildRequires:  %{python_module setuptools_scm >= 2.0.0}
BuildRequires:  %{python_module time-machine >= 2.13}
BuildRequires:  %{python_module tomli >= 2.0.1}
BuildRequires:  %{python_module virtualenv >= 20.24.3}
BuildRequires:  %{python_module wheel >= 0.42}
%if %{with devpi_process}
BuildRequires:  %{python_module devpi-process > 1}
%endif
BuildRequires:  %{python_module importlib-metadata >= 6.8}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-cachetools >= 5.3.2
Requires:       python-chardet >= 5.2
Requires:       python-colorama >= 0.4.6
Requires:       python-filelock >= 3.13.1
Requires:       python-packaging >= 23.2
Requires:       python-platformdirs >= 4.1
Requires:       python-pluggy >= 1.3
Requires:       python-pyproject-api >= 1.6.1
Requires:       python-virtualenv >= 20.24.3
Requires:       (python-importlib-metadata >= 0.12 if python-base < 3.8)
Requires:       (python-tomli >= 2.0.1 if python-base < 3.11)
Requires(post): update-alternatives
Requires(postun): update-alternatives
# last detox version is 0.19
Obsoletes:      python-detox <= 0.19
Provides:       python-detox > 0.19
BuildArch:      noarch
# SECTION setup.cfg [options.extras_requires] testing=
# (except for pytest-cov and -randomly)
BuildRequires:  %{python_module flaky >= 3.7.0}
BuildRequires:  %{python_module freezegun >= 0.3.11}
BuildRequires:  %{python_module numpy >= 1.25}
BuildRequires:  %{python_module psutil >= 5.9.5}
BuildRequires:  %{python_module pytest >= 7.4.4}
BuildRequires:  %{python_module pytest-cov >= 4.1}
BuildRequires:  %{python_module pytest-mock >= 3.12}
BuildRequires:  %{python_module pytest-xdist >= 3.3.1}
# /SECTION
%if "%{python_flavor}" == "python3" || "%{?python_provides}" == "python3"
Provides:       tox = %{version}
%endif
%python_subpackages

%description
Tox as is a generic virtualenv management and test command line tool you can
use for:

* checking your package installs correctly with different
  Python versions and interpreters

* running your tests in each of the
  environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration
  servers, greatly reducing boilerplate and merging
  CI and shell-based testing.

%prep
%setup -q -n tox-%{version}
%if %{without devpi_process}
%patch -P 0 -p1
%endif
%patch -P 1 -p1

%build
export LANG=en_US.UTF8
%pyproject_wheel

%install
export LANG=en_US.UTF8
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/tox
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Ignores for gh#tox-dev/tox#1293 -- these tests want to install specific wheels (including pytest) into tox envs
# Upstream suggests to  provide them manually to avoid downloading, but with indirect dependencies the number of
# wheels is too large. Plus, defining PIP_NO_INDEX PIP_FIND_LINKS as suggested will be deprecated in a future
# pip and it does not propagate  to the test calling pip themselves without patching.
# enscons are not packaged
donttest+=" or test_provision_missing or test_provision_interrupt_child or test_provision_from_pyvenv"
donttest+=" or test_provision_cli_args_ignore or test_provision_non_canonical_dep"
donttest+=" or test_test_usedevelop"
donttest+=" or test_different_config_cwd"
donttest+=" or test_toxuone_env"
donttest+=" or test_isolated_build_backend_missing_hook"
donttest+=" or test_parallel_live or (test_parallel and not test_parallel_)"
# gh#tox-dev/tox#3011
donttest+=" or test_replace_env_var_circular_flip_flop"
#
donttest+=" or test_call_as_exe or test_skip_pkg_install"
donttest+=" or test_python_generate_hash_seed"
# this test doesn't work on aarch64
donttest+=" or test_bad_env_var"
# this test doesn't work on Leap
donttest+=" or test_package_cmd_builder"
# gh#tox-dev/tox#3399
donttest+=" or test_skip_develop_mode"

%{python_expand # tests expect an active virtualenv with a clean python name as sys.executable
virtualenv-%{$python_bin_suffix} --system-site-packages testenv-%{$python_bin_suffix}
source testenv-%{$python_bin_suffix}/bin/activate
pip install --no-deps ./build/tox*.whl
python -B -m pytest -v -m "not network" -k "not (${donttest:4})" -n auto
deactivate
}

%post
%python_install_alternative tox

%postun
%python_uninstall_alternative tox

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/tox
%{python_sitelib}/tox-%{version}*-info
%{python_sitelib}/tox

%changelog
* Tue Oct  8 2024 Matej Cepl <mcepl@cepl.eu>
- Skip test_skip_develop_mode (gh#tox-dev/tox#3399)
- Rename patches:
  - 0001-Make-use-of-devpi_process-optional.patch to optional_devpi_process.patch
  - 0002-skip-test-which-require-network-access.patch to mark-network-tests.patch
  which removes these two patches:
  - 0001-Make-use-of-devpi_process-optional.patch
  - 0002-skip-test-which-require-network-access.patch
* Wed Mar 27 2024 ecsos <ecsos@opensuse.org>
- Fix build error in Leap.
  - Disable one more test.
  - Drop macro %%dnl because it works only in rpm version >= 4.15.
    Leap hast 4.14 at this time.
    Also enable it.
  - Fix some python3 typos in spec.
* Mon Mar 25 2024 Dan Čermák <dcermak@suse.com>
- Rebase patches:
  * optional_devpi_process.patch as 0001-Make-use-of-devpi_process-optional.patch
    (additionally add a skip of tests that would require the devpi process)
  * mark-network-tests.patch as 0002-skip-test-which-require-network-access.patch
- Bump dependencies according to upstream
- Remove unused dependency pytest-randomly
- New upstream release 4.14.2:
  v4.14.2 (2024-03-22)
  Bugfixes - 4.14.2
  ~~~~~~~~~~~~~~~~~
- Add provision arguments to ToxParser to fix crash when provisioning new tox environment without list-dependencies by :user:`seyidaniels` (:issue:`3190`)
  Improved Documentation - 4.14.2
  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- Removed unused line from the 'fresh_subprocess' documentation. (:issue:`3241`)
  v4.14.1 (2024-03-06)
  Bugfixes - 4.14.1
  ~~~~~~~~~~~~~~~~~
- Fix crash with fresh subprocess, if the build backend is setuptools automatically enable fresh subprocesses for
  build backend calls - by :user:`gaborbernat`. (:issue:`3235`)
  v4.14.0 (2024-03-05)
  Features - 4.14.0
  ~~~~~~~~~~~~~~~~~
- Support enabling fresh subprocess for packaging build backends via :ref:`fresh_subprocess` - by :user:`gaborbernat`. (:issue:`3227`)
- Allow plugins attaching additional information to ``--version`` via ``tox_append_version_info`` method in the plugin
  module - by :user:`gaborbernat`. (:issue:`3234`)
  v4.13.0 (2024-02-16)
  Features - 4.13.0
  ~~~~~~~~~~~~~~~~~
- Extract virtual environment packaging code to its own base class not tied to ``virtualenv`` - by :user:`gaborbernat`. (:issue:`3221`)
  Improved Documentation - 4.13.0
  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- Documented usage of ``pytest`` with ``tox run-parallel`` - by :user:`faph`. (:issue:`3187`)
- Configuration: state in config directive sections their ini file sections - by :user:`0cjs`. (:issue:`3194`)
- Development: summarize important points experienced developers need to know - by :user:`0cjs`. (:issue:`3197`)
  v4.12.1 (2024-01-16)
  Bugfixes - 4.12.1
  ~~~~~~~~~~~~~~~~~
- Fixed bug where running with --installpkg and multiple envs could not clean up between tests (:issue:`3165`)
  v4.12.0 (2024-01-11)
  Features - 4.12.0
  ~~~~~~~~~~~~~~~~~
- Always pass ``FORCE_COLOR`` and ``NO_COLOR`` to the environment (:issue:`3171`)
  Bugfixes - 4.12.0
  ~~~~~~~~~~~~~~~~~
- ``--parallel-no-spinner`` flag now implies ``--parallel`` (:issue:`3158`)
  Improved Documentation - 4.12.0
  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- -Fix ``open an issue`` link in development.rst (:issue:`3179`)
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 4.11.4:
  * Fix `quickstart` command from requiring `root` positional
    argument
  * docs(config): fix default value for install_command
  * Added Python 3.12 in installation docs
  * Fix terminal size in tox commands (#2999)
  * Use the new ruff formatter over black
  * docs(config): Fix base_python default reference
  * Fixed 'AppData' not passed to env by default (#3151)
* Thu Nov  9 2023 ecsos <ecsos@opensuse.org>
- Fix required versions for BuildRequires and Requieres to use
  right version and to can build under Leap.
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- update to 4.11.3:
  * docs(plugin): explain plugin registration
  * Fix error caused by a bad `base_python` path
  * Fix typos discovered by codespell
  * Providing example to make CLI help more helpful for -x,--
    override
  * Remove stray colons in `config.rst` left over from #3111
* Mon Sep  4 2023 Martin Schreiner <martin.schreiner@suse.com>
- Refresh mark-network-tests.patch for 4.11.1.
- Rewrite optional_devpi_process.patch for 4.11.1.
- Add explicit numpy built-time dependency, as the one pulled by
  pytest-randomly was broken.
- Fix rpmlint warning: package was obsoleting itself.
- Update to 4.11.1:
  - Changes from 4.11.1:
  * Tests: Don't assume Python 3.10 is always installed, use current
    Python version
  * Set the --parallel default to "auto", not CPU count
  * Fix , being used as value parser for env var configs
  - Changes from 4.11.0:
  * Fix type checker and bump tools
  * Add config_settings support for build backend calls
  - Changes from 4.10.0:
  * Set basepython for docs env in alignment to Read the Docs
    default
  * Document release process
  * Replace undefined settings with overrides when appending
  * Accept environments with defined factors or of python selector
    form - suggest closest
  - Changes from 4.9.0:
  * Disallow command line environments which are not explicitly
    specified in the config file
  - Changes from 4.8.0:
  * Correct "notset" typo in --hashseed's --help text
  * Bump pypa/gh-action-pypi-publish from 1.8.8 to 1.8.10
  * Allow extending lists with --override foo+=bar
  - Changes from 4.7.0:
  * Fix doc alignment and link check
  * Bump pypa/gh-action-pypi-publish from 1.8.7 to 1.8.8
  * Update a test regex to work with Python 3.12+
  * Remove broken link
  * Add sponsor button for tidelift
  * Make --hashseed default to PYTHONHASHSEED, if defined
  - Changes from 4.6.4:
  * Ensure tox r -e docs generates the documentation
  * Bump pypa/gh-action-pypi-publish from 1.8.6 to 1.8.7
  * s/setup.cfg/pyproject.toml/ in the development docs
  * Fix hang and zombie process on interrupt (CTRL-C)
  - Changes from 4.6.3:
  * Made issue template have less whitespace
  * Docs link of env var subs section to set_env
  * Removed duplicate text in bug report template
  * Ensure get_requires hook is called before prepare_metadata
  - Changes from 4.6.2:
  * Avoid cache collision between wheel and editable wheel builds
  - Changes from 4.6.1:
  * Update usedevelop doc
  * Use ruff
  - Changes from 4.6.0:
  * Remove unnecessary Future usage
  * Test against 3.12.0-beta.1
  * Add --list-dependencies options
  - Changes from 4.5.2:
  * Add 3.12 support
  * Bump pypa/gh-action-pypi-publish from 1.8.5 to 1.8.6
  * Update list of maintainers
  * Fix legacy tox --devenv venv
  * Fix legacy devenv
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Fix build error in Leap.
  Change %%autopatch -p1 -m 1 to %%patch1 -p1
* Fri Jun  2 2023 Dan Čermák <dcermak@suse.com>
- Fix requires & buildrequires
* Fri May  5 2023 Matej Cepl <mcepl@suse.com>
- Update to 4.5.1:
  The amount of changes is so huge, that user is kindly referred
  to the packaged changelog.
- Add mark-network-tests.patch to skip test which require network
  access
- Add optional_devpi_process.patch to make the package not depend
  on devpi_process (which is rather expensive to build).
- Add _constraints.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Jan 19 2023 Michal Suchanek <msuchanek@suse.com>
- Add missing python-tomli dependency.
* Tue Oct 25 2022 Matej Cepl <mcepl@suse.com>
- Remove python2-related parts of the SPEC file.
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.26.0
  Bugfixes
  * Fix fallback to python environment when isolated_build = true is set – by @Unrud #2474
  * Fixed SetuptoolsDeprecationWarning about using --global-option – by @adamchainz #2478
* Sun Jul 24 2022 Dirk Müller <dmueller@suse.com>
- update to 3.25.1:
  * ``sitepackages = true`` will add user's site-package to the python path on Windows as expected
  * Avoid importing ``pipes`` on Python 3.3+ to avoid ``DeprecationWarning`` on Python 3.11
  * Fix ``isolated_build`` when the build process produces stderr at exit.
  * Fixed failing isolated_build because setuptools warning was captured
    in ``build_requires``.
  * Avoid potential 30s delay caused by socket.getfqdn().
  * Ignore missing commands if they are prefixed by ``-``
* Thu Dec 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Drop definition of python-tox-doc: this subpackage is not being
  built.
* Sun Sep 26 2021 Matej Cepl <mcepl@suse.com>
- Update to 3.24.4:
  - Fixed handling of -e ALL in parallel mode by ignoring the ALL
    in subprocesses -- by :user:`guahki`. #2167
  - Prevent tox from using a truncated interpreter when using
    TOX_LIMITED_SHEBANG -- by :user:`jdknight`. #2208
  - Enabled the use of the favicon in the Sphinx docs first
    introduced in :pull:`764` but not integrated fully --
    :user:`webknjaz` #2177
  - --parallel reports now show ASCII OK/FAIL/SKIP lines when
    full Unicode output is not available - by :user:`brettcs`
    [#1421]
  - Started enforcing valid references in Sphinx docs --
    :user:`webknjaz` #2168
  - include LC_ALL to implicit list of passenv variables - by
    :user:`ssbarnea` #2162
  - get_requires_for_build_sdist hook (PEP 517) is assumed to
    return an empty list if left unimplemented by the backend
    build system - by :user:`oczkoisse` #2130
  - The documentation of install_command now also mentions that
    you can provide arbitrary commands - by :user:`jugmac00`
    [#2081]
  - --devenv no longer modifies the directory in which the .tox
    environment is provisioned - by :user:`isaac-ped` #2065
  - Fix show config when the package names are not in canonical
    form - by :user:`gaborbernat`. #2103
  - Extended environment variables section - by :user:`majiang`
    [#2036]
  - tox no longer shows deprecation warnings for
    distutils.sysconfig on Python 3.10 - by :user:`9999years`
    [#2100]
  - Distinguish between normal Windows Python and MSYS2 Python
    when looking for virtualenv executable path. Adds os.sep to
    :class:`~tox.interpreters.InterpreterInfo` - by
    :user:`jschwartzentruber` #1982
  - Fix a tox-conda isolation build bug - by :user:`AntoineD`.
    [#2056]
  - Update examples in the documentation to use setenv in the
    [testenv] sections, not wrongly in the [tox] main section.
  - by :user:`AndreyNautilus` #1999
  - Enable building tox with setuptools_scm 6+ by :user:`hroncok`
    [#1984]
  - tox can now be invoked with a new --no-provision flag that
    prevents provision, if :conf:`requires` or :conf:`minversion`
    are not satisfied, tox will fail; if a path is specified as
    an argument to the flag (e.g. as tox --no-provision
    missing.json) and provision is prevented, provision metadata
    are written as JSON to that path - by :user:`hroncok` #1921
  - Unicode support in pyproject.toml - by :user:`domdfcoding`
    [#1940]
  - The value of the :conf:`requires` configuration option is now
    exposed via the :class:`tox.config.Config` object - by
    :user:`hroncok` #1918
  - Adapt tests not to assume the easy_install command exists, as
    it was removed from setuptools 52.0.0+ - by :user:`hroncok`
    [#1893]
  - Fix a killed tox (via SIGTERM) leaving the commands
    subprocesses running by handling it as if it were
    a KeyboardInterrupt - by :user:`dajose` #1772
  - Newer coverage tools update the COV_CORE_CONTEXT environment
    variable, add it to the list of environment variables that
    can change in our pytest plugin - by :user:`gaborbernat`.
    [#1854]
* Mon Feb 22 2021 Ben Greiner <code@bnavigator.de>
- Fix wheel location when custom installing into test venv.
* Sun Jan 17 2021 Benjamin Greiner <code@bnavigator.de>
- Update requirements
- Fix the test suite failure introduced by the switch to
  coinstallable python3 flavors: must be called with plain python
  name for sys.executable to not detect the minor version as
  binary extension (python3.8 --> magic.8)
* Wed Jan 13 2021 John Vandenberg <jayvdb@gmail.com>
- Remove build dependency on pytest-cov
- Re-enable test_create_KeyboardInterrupt and spinner tests
- Update to v3.21.1
  * Fix regression that broke using install_command in config
    replacements
  * Fix regression parsing posargs default containing colon
  * Prevent .tox in envlist
  * Enable building tox with ``setuptools_scm`` 4 and 5
- from v3.21.0
  * Fix the false ``congratulations`` message that appears when
    a ``KeyboardInterrupt`` occurs during package installation
  * Fix ``platform`` support for ``install_command``
  * Fixed regression in v3.20.0 that caused escaped curly braces
    in setenv to break usage of the variable elsewhere in tox.ini
  * Prevent ``{}`` and require ``{:`` is only followed by ``}``
  * Raise ``MissingSubstitution`` on access of broken ini setting
  * Allow \{ and \} in default of {env:key:default}
  * Allow {posargs} in setenv
  * Allow {/} to refer to os.sep
  * Make parsing [testenv] sections in setup.cfg official
  * Relax importlib requirement to allow 3.0.0 or any newer version
  * Document more info about using ``platform`` setting
  * Replace ``indexserver`` in documentation with environment
    variables
  * Document that the ``passenv`` environment setting is case
  insensitive
- from v3.20.1
  * Relax importlib requirement to allow version<3
- from v3.20.0
  * Allow hyphens and empty factors in generative section name
  * Support for PEP517 in-tree build backend-path key in
    ``get-build-requires``
  * Allow escaping curly braces in setenv
  * Support for comments within ``setenv`` and environment files via
    the ``files|`` prefix
- from v3.19.0
  * skip ``setup.cfg`` if it has no ``tox:tox`` namespace
  * Implement support for building projects having pep 517
    (in-tree-build-backends) ``backend-path`` setting
  * Don't require a tox config file for ``tox
  * Fixed grammar in top-level documentation
- from v3.18.1
  * Fix ``TypeError`` when using isolated_build with backends
    that are not submodules
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.18.0
  * Add allowlist_externals alias to whitelist_externals (whitelist_externals is now deprecated). - by :user:`dajose`
  * Fix tests when the ``HOSTNAME`` environment variable is set, but empty string - by :user:`hroncok`
  * The long arguments ``--verbose`` and ``--quiet`` (rather than only their short forms, ``-v`` and ``-q``) are now accepted.
  * The ``ResultLog`` now prefers ``HOSTNAME`` environment variable value (if set) over the full qualified domain name of localhost.
    This makes it possible to disable an undesired DNS lookup,
    which happened on all ``tox`` invocations, including trivial ones * by :user:`hroncok`
  * Update packaging information for Flit.
  * Fixed the support for using ``{temp_dir}`` in ``tox.ini`` - by :user:`webknjaz`
  * Allow skipping the package and installation step when passing the ``--skip-pkg-install``.
* Fri Jun 26 2020 Thomas Bechtold <tbechtold@suse.com>
- update to 3.15.2:
  - Add an option to allow a process to suicide before sending the
    SIGTERM.
  - PyPy 7.3.1 on Windows uses the 'Script' folder instead of
    'bin'.
* Wed May 20 2020 Michael Ströder <michael@stroeder.com>
- version update to 3.15.1
  * Allow parallel mode without arguments.
  * Allow generative section name expansion.
  * default to passing the env var PIP_EXTRA_INDEX_URL
  * some bug fixes
* Fri Apr 17 2020 pgajdos@suse.com
- version update to 3.14.6
  - Exclude virtualenv depencency versions with known
    regressions (20.0.[0-7]) - by :user:`webknjaz`.
    `#1537 <https://github.com/tox-dev/tox/issues/1537>`_
  - Fix ``tox -h`` and ``tox --hi`` shows an error when run outside a directory with tox support files by :user:`nkpro2000sr`.
    `#1539 <https://github.com/tox-dev/tox/issues/1539>`_
* Fri Mar 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable spinner tests as the monkeypatch changed behaviour in pytest
* Wed Mar 11 2020 pgajdos@suse.com
- version update to 3.14.5
  - Add ``--discover`` (fallback to ``TOX_DISCOVER`` environment variable via path separator) to inject python executables
    to try as first step of a discovery - note the executable still needs to match the environment by :user:`gaborbernat`.
    `#1526 <https://github.com/tox-dev/tox/issues/1526>`_
  - Bump minimal six version needed to avoid using one incompatible with newer
    virtualenv. - by :user:`ssbarnea`
    `#1519 <https://github.com/tox-dev/tox/issues/1519>`_
  - Avoid pypy test failure due to undefined printout var. - by :user:`ssbarnea`
    `#1521 <https://github.com/tox-dev/tox/issues/1521>`_
* Fri Feb  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.14.3 bsc#1163043:
  * Relax importlib requirement to allow either version 0 or 1 - by :user:`chyzzqo2` #1476
* Sun Nov 17 2019 Hans-Peter Jansen <hpj@urpla.net>
- Disable another failing test
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.14.0:
  * Fix PythonSpec detection of python3.10
  * Fix regression failing to detect future and past py## factors
  * Fix current_tox_py for pypy / pypy3
  * Add support for minor versions with multiple digits
  * Remove dependence on md5 hashing algorithm
  * on venv cleanup: add explicit check for pypy venv to make it possible to recreate it
  * Fix isolated build double-requirement
  * Replace pkg_resources with importlib_metadata for speed
* Fri May 24 2019 Matej Cepl <mcepl@suse.com>
- Update to 3.12.1:
  - Ensure TOX_WORK_DIR is a native string in os.environ
  - Fix import and usage of winreg for python2.7 on windows
  - Fix Windows selects incorrect spec on first discovery
  - When using --parallel with --result-json the test results are
    now included the same way as with serial runs
  - Turns out the output of the py -0p is not stable yet and
    varies depending on various edge cases. Instead now we read
    the interpreter values directly from registry via PEP-514
  - Adding TOX_PARALLEL_NO_SPINNER environment variable to
    disable the spinner in parallel mode for the purposes of
    clean output when using CI tools
* Thu May 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.11.1:
  * When creating virtual environments we no longer ask the python to tell
    its path, but rather use the discovered path.
* Wed May 15 2019 Jonathan Harker <jharker@suse.com>
- Update to 3.11.0:
  * --showconfig overhaul
* Mon May 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.10.0:
  * Please see changelog.rst
* Thu Mar 28 2019 Matej Cepl <mcepl@suse.com>
- Update to 3.8.1:
  - Bugfixes
  - The -eALL command line argument now expands the envlist key
    and includes all its environment. #1155
  - Isolated build environment dependency overrides were not
    taken in consideration (and such it inherited the deps from
    the testenv section)
  - --result-json puts the command into setup section instead
    of test (pre and post commands are now also correctly put
    into the commands section)
  - Set setup.cfg encoding to UTF-8 as it contains Unicode
    characters. #1212
  - Fix tox CI, better error reporting when locating via the py
    fails
  - In a posix shell, setting the PATH environment variable to
    an empty value is equivalent to not setting it at all;
    therefore we no longer if the user sets PYTHONPATH an empty
    string on python 3.4 or later
  - Fixed bug of children process calls logs clashing (log
    already exists)
  - Interpreter discovery and virtualenv creation process calls
    that failed will now print out on the screen their output
    (via the logfile we automatically save)
  - Using py2 and py3 with a specific basepython will no longer
    raise a warning unless the major version conflicts
  - Fix missing error for tox -e unknown when tox.ini declares
    envlist.
  - Resolve symlinks with toxworkdir.
  - Interrupting a tox call (e.g. via CTRL+C) now will ensure
    that spawn child processes (test calls, interpreter
    discovery, parallel sub-instances, provisioned hosts) are
    correctly stopped before exiting (via the pattern of
    INTERRUPT - 300 ms, TERMINATE - 200 ms, KILL signals)
  - Fix a ResourceWarning: unclosed file in Action
  - Fix deadlock when using --parallel and having environments
    with lots of output
  - Removed code that sometimes caused a difference in results
    between --parallel and -p when using posargs
  - Features
  - tox now auto-provisions itself if needed (see
    :ref:`auto-provision`). Plugins or minimum version of tox
    no longer need to be manually satisfied by the user,
    increasing their ease of use.
  - tox will inject the TOX_PARALLEL_ENV environment variable,
    set to the current running tox environment name, only when
    running in parallel mode.
  - Parallel children now save their output to a disk logfile
  - Parallel children now are added to --result-json
  - Display pattern and sys.platform with platform mismatch
  - Setting the environment variable TOX_REPORTER_TIMESTAMP to
    1 will enable showing for each output line its delta since
    the tox startup. This can be especially handy when
    debugging parallel runs.
  - Documentation
  - Add a poetry examples to packaging
- Switch build macros to PEP-518 compatible ones
* Tue Mar 12 2019 Matej Cepl <mcepl@suse.com>
- Update to 3.7.0:
  - Parallel mode added (alternative to detox which is being
    deprecated), for more details see `parallel_mode`
  - Added command line shortcut -s for
  - -skip-missing-interpreters
  - Whitelisting of externals will be mandatory in tox 4: issue
    a deprecation warning as part of the already existing warning
  - Clarify explanations in examples and avoid unsupported end
    line comments
  - Set to PULL_REQUEST_TEMPLATE.md use relative instead of
    absolute URLs
  - if the packaging phase successfully builds a package set it
    as environment variable under TOX_PACKAGE (useful to make
    assertions on the built package itself, instead of just how
    it ends up after installation)
  - On windows, check sys.executable before others for
    interpreter version lookup. This matches what happens on
    non-windows.
  - Don't rewrite {posargs} substitution for absolute paths.
  - Correctly fail tox --notest when setup fails.
  - Link to related projects (Invoke and Nox) from the
    documentation
- Obsoletes python-detox.
* Thu Oct 18 2018 Tomáš Chvátal <tchvatal@suse.com>
- Make sure the tests are executed
* Fri Oct 12 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * require filelock
  * CHANGELOG.rst ->changelog.rst, added CONTRIBUTORS CONTRIBUTING.rst to doc
  * add fdupes
- update to version 3.5.2:
  * Bugfixes
    + session packages are now put inside a numbered directory
    (instead of prefix numbering it, because pip fails when wheels
    are not named according to `PEP-491
    <https://www.python.org/dev/peps/pep-0491/#id9>`_, and prefix
    numbering messes with this) - by :user:`gaborbernat` (`#1042
    <https://github.com/tox-dev/tox/issues/1042>`_)
  * Features
    + level three verbosity ("-vvv") show the packaging output - by
    :user:`gaborbernat` (`#1047
    <https://github.com/tox-dev/tox/issues/1047>`_)
- changes from version 3.5.1:
  * Bugfixes
    + fix regression with "3.5.0": specifying "--installpkg" raises
    "AttributeError: 'str' object has no attribute 'basename'"
    (`#1042 <https://github.com/tox-dev/tox/issues/1042>`_)
- changes from version 3.5.0:
  * Bugfixes
    + intermittent failures with "--parallel--safe-build", instead of
    mangling with the file paths now uses a lock to make the package
    build operation thread safe and is now on by default
    ("--parallel--safe-build" is now deprecated) - by
    :user:`gaborbernat` (`#1026
    <https://github.com/tox-dev/tox/issues/1026>`_)
  * Features
    + Added "temp_dir" folder configuration (defaults to
    "{toxworkdir}/.tmp") that contains tox temporary files. Package
    builds now create a hard link (if possible, otherwise copy -
    notably in case of Windows Python 2.7) to the built file, and
    feed that file downstream (e.g. for pip to install it). The hard
    link is removed at the end of the run (what it points though is
    kept inside "distdir"). This ensures that a tox session operates
    on the same package it built, even if a parallel tox run builds
    another version. Note "distdir" will contain only the last built
    package in such cases. - by :user:`gaborbernat` (`#1026
    <https://github.com/tox-dev/tox/issues/1026>`_)
  * Documentation
    + document tox environment recreate rules (:ref:`recreate`) - by
    :user:`gaborbernat` (`#93
    <https://github.com/tox-dev/tox/issues/93>`_)
    + document inside the "--help" how to disable colorized output via
    the "PY_COLORS" operating system environment variable - by
    :user:`gaborbernat` (`#163
    <https://github.com/tox-dev/tox/issues/163>`_)
    + document all global tox flags and a more concise format to
    express default and type - by :user:`gaborbernat` (`#683
    <https://github.com/tox-dev/tox/issues/683>`_)
    + document command line interface under the config section `cli
    <https://tox.readthedocs.io/en/latest/config.html?highlight=cli#cli>`_
  - by :user:`gaborbernat` (`#829
    <https://github.com/tox-dev/tox/issues/829>`_)
- changes from version 3.4.0:
  * Bugfixes
    + add "--exists-action w" to default pip flags to handle better
    VCS dependencies (`pip documentation on this
    <https://pip.pypa.io/en/latest/reference/pip/#exists-action-option>`_)
  - by :user:`gaborbernat` (`#503
    <https://github.com/tox-dev/tox/issues/503>`_)
    + instead of assuming the Python version from the base python name
    ask the interpreter to reveal the version for the
    "ignore_basepython_conflict" flag - by :user:`gaborbernat`
    (`#908 <https://github.com/tox-dev/tox/issues/908>`_)
    + PEP-517 packaging fails with sdist already exists, fixed via
    ensuring the dist folder is empty before invoking the backend
    and `pypa/setuptools 1481
    <https://github.com/pypa/setuptools/pull/1481>`_ - by
    :user:`gaborbernat` (`#1003
    <https://github.com/tox-dev/tox/issues/1003>`_)
  * Features
    + add "commands_pre" and "commands_post" that run before and after
    running the "commands" (setup runs always, commands only if
    setup suceeds, teardown always - all run until the first failing
    command) - by :user:`gaborbernat` (`#167
    <https://github.com/tox-dev/tox/issues/167>`_)
    + "pyproject.toml" config support initially by just inline the
    tox.ini under "tool.tox.legacy_tox_ini" key; config source
    priority order is "pyproject.toml", "tox.ini" and then
    "setup.cfg" - by :user:`gaborbernat` (`#814
    <https://github.com/tox-dev/tox/issues/814>`_)
    + use the os environment variable "TOX_SKIP_ENV" to filter out tox
    environment names from the run list (set by "envlist") - by
    :user:`gaborbernat` (`#824
    <https://github.com/tox-dev/tox/issues/824>`_)
    + always set "PIP_USER=0" (do not install into the user site
    package, but inside the virtual environment created) and
    "PIP_NO_DEPS=0" (installing without dependencies can cause
    broken package installations) inside tox - by
    :user:`gaborbernat` (`#838
    <https://github.com/tox-dev/tox/issues/838>`_)
    + tox will inject some environment variables that to indicate a
    command is running within tox: "TOX_WORK_DIR" env var is set to
    the tox work directory, "TOX_ENV_NAME" is set to the current
    running tox environment name, "TOX_ENV_DIR" is set to the
    current tox environments working dir - by :user:`gaborbernat`
    (`#847 <https://github.com/tox-dev/tox/issues/847>`_)
    + While running tox invokes various commands (such as building the
    package, pip installing dependencies and so on), these were
    printed in case they failed as Python arrays. Changed the
    representation to a shell command, allowing the users to quickly
    replicate/debug the failure on their own - by
    :user:`gaborbernat` (`#851
    <https://github.com/tox-dev/tox/issues/851>`_)
    + skip missing interpreters value from the config file can now be
    overridden via the "--skip-missing-interpreters" cli flag - by
    :user:`gaborbernat` (`#903
    <https://github.com/tox-dev/tox/issues/903>`_)
    + keep additional environments config order when listing them - by
    :user:`gaborbernat` (`#921
    <https://github.com/tox-dev/tox/issues/921>`_)
    + allow injecting config value inside the ini file dependent of
    the fact that we're connected to an interactive shell or not -
    by :user:`gaborbernat` (`#947
    <https://github.com/tox-dev/tox/issues/947>`_)
    + do not build sdist if skip install is specified for the envs to
    be run - by :user:`gaborbernat` (`#974
    <https://github.com/tox-dev/tox/issues/974>`_)
    + when verbosity level increases above two start passing through
    verbosity flags to pip - by :user:`gaborbernat` (`#982
    <https://github.com/tox-dev/tox/issues/982>`_)
    + when discovering the interpreter to use check if the tox host
    Python matches and use that if so - by :user:`gaborbernat`
    (`#994 <https://github.com/tox-dev/tox/issues/994>`_)
    + "-vv" will print out why a virtual environment is re-created
    whenever this operation is triggered - by :user:`gaborbernat`
    (`#1004 <https://github.com/tox-dev/tox/issues/1004>`_)
  * Documentation
    + clarify that "python" and "pip" refer to the virtual
    environments executable - by :user:`gaborbernat` (`#305
    <https://github.com/tox-dev/tox/issues/305>`_)
    + add Sphinx and mkdocs example of generating documentation via
    tox - by :user:`gaborbernat` (`#374
    <https://github.com/tox-dev/tox/issues/374>`_)
    + specify that "setup.cfg" tox configuration needs to be inside
    the "tox:tox" namespace - by :user:`gaborbernat` (`#545
    <https://github.com/tox-dev/tox/issues/545>`_)
* Tue Sep 11 2018 dmueller@suse.com
- update to 3.3.0:
  - fix ``TOX_LIMITED_SHEBANG`` when running under python3 - by :user:`asottile` (`#931 <https://github.com/tox-dev/tox/issues/931>`_)
  - `PEP-517 <https://www.python.org/dev/peps/pep-0517/>`_ source distribution support (create a
    ``.package`` virtual environment to perform build operations inside) by :user:`gaborbernat` (`#573 <https://github.com/tox-dev/tox/issues/573>`_)
  - `flit <https://flit.readthedocs.io>`_ support via implementing ``PEP-517`` by :user:`gaborbernat` (`#820 <https://github.com/tox-dev/tox/issues/820>`_)
  - packaging now is exposed as a hook via ``tox_package(session, venv)`` - by :user:`gaborbernat` (`#951 <https://github.com/tox-dev/tox/issues/951>`_)
  - Updated the VSTS build YAML to use the latest jobs and pools syntax - by :user:`davidstaheli` (`#955 <https://github.com/tox-dev/tox/issues/955>`_)
  - ``--parallel--safe-build`` no longer cleans up its folders (``distdir``, ``distshare``, ``log``). - by :user:`gaborbernat` (`#849 <https://github.com/tox-dev/tox/issues/849>`_)
  - Switch pip invocations to use the module ``-m pip`` instead of direct invocation. This could help
    avoid some of the shebang limitations.  - by :user:`gaborbernat` (`#935 <https://github.com/tox-dev/tox/issues/935>`_)
  - Ability to specify package requirements for the tox run via the ``tox.ini`` (``tox`` section under key ``requires`` - PEP-508 style): can be used to specify both plugin requirements or build dependencies. - by :user
  :`gaborbernat` (`#783 <https://github.com/tox-dev/tox/issues/783>`_)
  - Allow to run multiple tox instances in parallel by providing the
    ``--parallel--safe-build`` flag. - by :user:`gaborbernat` (`#849 <https://github.com/tox-dev/tox/issues/849>`_)
  - A caching issue that caused the ``develop-inst-nodeps`` action, which
    reinstalls the package under test, to always run has been resolved. The
    ``develop-inst-noop`` action, which, as the name suggests, is a no-op, will now
    run unless there are changes to ``setup.py`` or ``setup.cfg`` files that have
    not been reflected - by @stephenfin (`#909 <https://github.com/tox-dev/tox/issues/909>`_)
* Tue Jul 17 2018 tchvatal@suse.com
- Version update to 3.1.2:
  * Many changes in the code, dropped support for py <2.7 and <3.3
  * See CHANGELOG.rst
- Do not build sphinx documentation, additional dependencies
* Fri Dec 22 2017 dimstar@opensuse.org
- Fix generation of html documentation.
* Sat Sep 30 2017 arun@gmx.de
- specfile:
  * change CHANGELOG -> CHANGELOG.rst
  * added setuptools_scm requirement
- update to version 2.9.1:
  * Misc
    + integrated new release process and fixed changelog rendering for
    pypi.org - by @obestwalter.
- changes from version 2.9.0:
  * Features
    + tox --version now shows information about all registered plugins
  - by @obestwalter (#544)
  * Bugfixes
    + skip_install overrides usedevelop (usedevelop is an option to
    choose the installation type if the package is installed and
    skip_install determines if it should be installed at all) - by
    @ferdonline (#571)
  * Misc
    + #635 inherit from correct exception - by @obestwalter (#635).
    + spelling and escape sequence fixes - by @scoop (#637 and #638).
    + add a badge to show build status of documentation on
    readthedocs.io - by @obestwalter.
  * Improved Documentation
    + add towncrier to allow adding changelog entries with the pull
    requests without generating merge conflicts; with this release
    notes are now grouped into four distinct collections: Features,
    Bugfixes, Improved Documentation and Deprecations and
    Removals. (#614)
- changes from version 2.8.2:
  * #466: stop env var leakage if popen failed with resultjson or
    redirect
- changes from version 2.8.1:
  * pull request 599: fix problems with implementation of
    [#515]. Substitutions from other sections were not made anymore if
    they were not in envlist. Thanks to Clark Boylan (@cboylan) for
    helping to get this fixed (pull request 597).
- changes from version 2.8.0:
  * #276: Remove easy_install from docs (TL;DR: use pip). Thanks
    Martin Andrysík (@sifuraz).
  * #301: Expand nested substitutions in tox.ini. Thanks
    @vlaci. Thanks to Eli Collins (@eli-collins) for creating a
    reproducer.
  * #315: add --help and --version to helptox-quickstart. Thanks
    @vlaci.
  * #326: Fix OSError 'Not a directory' when creating env on Jython
    2.7.0. Thanks Nick Douma (@LordGaav).
  * #429: Forward MSYSTEM by default on Windows. Thanks Marius
    Gedminas (@mgedmin) for reporting this.
  * #449: add multi platform example to the docs. Thanks Aleks Bunin
    (@sashkab) and @rndr.
  * #474: Start using setuptools_scm for tag based versioning.
  * #484: Renamed py.test to pytest throughout the project. Thanks
    Slam (@3lnc).
  * #504: With -a: do not show additional environments header if there
    are none. Thanks @rndr.
  * #515: Don't require environment variables in test environments
    where they are not used. Thanks André Caron (@AndreLouisCaron).
  * #517: Forward NUMBER_OF_PROCESSORS by default on Windows to fix
    multiprocessor.cpu_count(). Thanks André Caron
    (@AndreLouisCaron).
  * #518: Forward USERPROFILE by default on Windows. Thanks André
    Caron (@AndreLouisCaron).
  * pull request 528: Fix some of the warnings displayed by pytest
    3.1.0. Thanks Bruno Oliveira (@nicoddemus).
  * pull request 547: Add regression test for #137. Thanks Martin
    Andrysík (@sifuraz).
  * pull request 553: Add an XFAIL test to reproduce upstream bug
    [#203]. Thanks Bartolomé Sánchez Salado (@bartsanchez).
  * pull request 556: Report more meaningful errors on why virtualenv
    creation failed. Thanks @vlaci. Also thanks to Igor Sadchenko
    (@igor-sadchenko) for pointing out a problem with that PR before
    it hit the masses ☺
  * pull request 575: Add announcement doc to end all announcement
    docs (using only CHANGELOG and Github issues since 2.5 already).
  * pull request 580: Do not ignore Sphinx warnings anymore. Thanks
    Bernát Gábor (@gaborbernat).
  * pull request 585: Expand documentation to explain pass through of
    flags from deps to pip (e.g. -rrequirements.txt,
  - cconstraints.txt). Thanks Alexander Loechel (@loechel).
  * pull request 588: Run pytest wit xfail_strict and adapt affected
    tests.
* Sat May  6 2017 toddrme2178@gmail.com
- Only one package should provide "tox".
* Fri Apr  7 2017 jmatejek@suse.com
- update for singlespec
- improve test runner, drop tox-disable-env-tests.patch
- split off common python-tox-doc subpackage
- update to 2.7.0
  * improve environment information for users
  * add "alwayscopy" config option
  * slightly backwards-incompatible fix for {posargs} substitution
  * add Python 3.6 and 3.7 support
  * more bugfixes, see CHANGELOG for more details
* Mon Feb 20 2017 dmueller@suse.com
- add a "tox" provides that helps finding it for non-SUSE users
* Wed Apr  6 2016 hpj@urpla.net
- remove failing test: test_force_dep_with_url; requires network
  update tox-disable-env-tests.patch
* Mon Feb  8 2016 tbechtold@suse.com
- update to 2.3.1:
  * fix issue294: re-allow cross-section substitution for setenv.
  * DEPRECATE use of "indexservers" in tox.ini.  It complicates
    the internal code and it is recommended to rather use the
    devpi system for managing indexes for pip.
  * fix issue285: make setenv processing fully lazy to fix regressions
    of tox-2.2.X and so that we can now have testenv attributes like
    "basepython" depend on environment variables that are set in
    a setenv section. Thanks Nelfin for some tests and initial
    work on a PR.
  * allow "#" in commands.  This is slightly incompatible with commands
    sections that used a comment after a "\" line continuation.
    Thanks David Stanek for the PR.
  * fix issue289: fix build_sphinx target, thanks Barry Warsaw.
  * fix issue252: allow environment names with special characters.
    Thanks Julien Castets for initial PR and patience.
  * introduce experimental tox_testenv_create(venv, action) and
    tox_testenv_install_deps(venv, action) hooks to allow
    plugins to do additional work on creation or installing
    deps.  These hooks are experimental mainly because of
    the involved "venv" and session objects whose current public
    API is not fully guranteed.
  * internal: push some optional object creation into tests because
    tox core doesn't need it.
  * fix bug where {envdir} substitution could not be used in setenv
    if that env value is then used in {basepython}. Thanks Florian Bruhin.
  * fix issue265 and add LD_LIBRARY_PATH to passenv on linux by default
    because otherwise the python interpreter might not start up in
    certain configurations (redhat software collections).  Thanks David Riddle.
  * fix issue246: fix regression in config parsing by reordering
    such that {envbindir} can be used again in tox.ini. Thanks Olli Walsh.
  * fix issue99: the {env:...} substitution now properly uses environment
    settings from the ``setenv`` section. Thanks Itxaka Serrano.
  * fix issue281: make --force-deps work when urls are present in
    dependency configs.  Thanks Glyph Lefkowitz for reporting.
  * fix issue174: add new ``ignore_outcome`` testenv attribute which
    can be set to True in which case it will produce a warning instead
    of an error on a failed testenv command outcome.
    Thanks Rebecka Gulliksson for the PR.
  * fix issue280: properly skip missing interpreter if
    {envsitepackagesdir} is present in commands. Thanks BB:ceridwenv
- Refresh tox-disable-env-tests.patch
* Wed Sep 16 2015 rhafer@suse.com
- (Build)Require python-pluggy
- refreshed tox-disable-env-tests.patch
- Update to 2.1.1:
  * fix platform skipping for detox
  * report skipped platforms as skips in the summary
- additional changes from version 2.1.0
  * fix issue258, fix issue248, fix issue253: for non-test commands
    (installation, venv creation) we pass in the full invocation environment.
  * remove experimental --set-home option which was hardly used and
    hackily implemented (if people want home-directory isolation we should
    figure out a better way to do it, possibly through a plugin)
  * fix issue259: passenv is now a line-list which allows to intersperse
    comments.  Thanks stefano-m.
  * allow envlist to be a multi-line list, to intersperse comments
    and have long envlist settings split more naturally.  Thanks Andre Caron.
  * introduce a TOX_TESTENV_PASSENV setting which is honored
    when constructing the set of environment variables for test environments.
    Thanks Marc Abramowitz for pushing in this direction.
- additional changes from version 2.0.2
  * fix issue247: tox now passes the LANG variable from the tox invocation
    environment to the test environment by default.
  * add SYSTEMDRIVE into default passenv on windows to allow pip6 to work.
    Thanks Michael Krause.
- additional changes from version 2.0.1
  * fix wheel packaging to properly require argparse on py26.
- additional changes from version 2.0.0
  * (new) introduce environment variable isolation:
    tox now only passes the PATH and PIP_INDEX_URL variable from the tox
    invocation environment to the test environment and on Windows
    also ``SYSTEMROOT``, ``PATHEXT``, ``TEMP`` and ``TMP`` whereas
    on unix additionally ``TMPDIR`` is passed.  If you need to pass
    through further environment variables you can use the new ``passenv`` setting,
    a space-separated list of environment variable names.  Each name
    can make use of fnmatch-style glob patterns.  All environment
    variables which exist in the tox-invocation environment will be copied
    to the test environment.
  * a new ``--help-ini`` option shows all possible testenv settings and
    their defaults.
  * (new) introduce a way to specify on which platform a testenvironment is to
    execute: the new per-venv "platform" setting allows to specify
    a regular expression which is matched against sys.platform.
    If platform is set and doesn't match the platform spec in the test
    environment the test environment is ignored, no setup or tests are attempted.
  * (new) add per-venv "ignore_errors" setting, which defaults to False.
    If ``True``, a non-zero exit code from one command will be ignored and
    further commands will be executed (which was the default behavior in tox <
    2.0).  If ``False`` (the default), then a non-zero exit code from one command
    will abort execution of commands for that environment.
  * show and store in json the version dependency information for each venv
  * remove the long-deprecated "distribute" option as it has no effect these days.
  * fix issue233: avoid hanging with tox-setuptools integration example. Thanks simonb.
  * fix issue120: allow substitution for the commands section.  Thanks
    Volodymyr Vitvitski.
  * fix issue235: fix AttributeError with --installpkg.  Thanks
    Volodymyr Vitvitski.
  * tox has now somewhat pep8 clean code, thanks to Volodymyr Vitvitski.
  * fix issue240: allow to specify empty argument list without it being
    rewritten to ".".  Thanks Daniel Hahler.
  * introduce experimental (not much documented yet) plugin system
    based on pytest's externalized "pluggy" system.
    See tox/hookspecs.py for the current hooks.
  * introduce parser.add_testenv_attribute() to register an ini-variable
    for testenv sections.  Can be used from plugins through the
    tox_add_option hook.
  * rename internal files -- tox offers no external API except for the
    experimental plugin hooks, use tox internals at your own risk.
  * DEPRECATE distshare in documentation
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 1.9.2:
  * backout ability that --force-deps substitutes name/versions in
    requirement files due to various issues. This fixes issue228,
    fixes issue230, fixes issue231 which popped up with 1.9.1.
- additional changes from version 1.9.1:
  * use a file instead of a pipe for command output in
    "--result-json". Fixes some termination issues with python2.6.
  * allow --force-deps to override dependencies in "-r"
    requirements files.  Thanks Sontek for the PR.
  * fix issue227: use "-m virtualenv" instead of "-mvirtualenv" to
    make it work with pyrun.  Thanks Marc-Andre Lemburg.
- additional changes from version 1.9.0:
  * fix issue193: Remove ``--pre`` from the default
    ``install_command``; by default tox will now only install final
    releases from PyPI for unpinned dependencies. Use ``pip_pre =
    true`` in a testenv or the ``--pre`` command-line option to
    restore the previous behavior.
  * fix issue199: fill resultlog structure ahead of virtualenv
    creation
  * refine determination if we run from Jenkins, thanks Borge Lanes.
  * echo output to stdout when ``--report-json`` is used
  * fix issue11: add a ``skip_install`` per-testenv setting which
    prevents the installation of a package. Thanks Julian Krause.
  * fix issue124: ignore command exit codes; when a command has a
    "-" prefix, tox will ignore the exit code of that command
  * fix issue198: fix broken envlist settings, e.g.
    {py26,py27}{-lint,}
  * fix issue191: lessen factor-use checks
- additional changes from version 1.8.1:
  * fix issue190: allow setenv to be empty.
  * allow escaping curly braces with "\".  Thanks Marc Abramowitz
    for the PR.
  * allow "." names in environment names such that "py27-django1.7"
    is a valid environment name.  Thanks Alex Gaynor and Alex
    Schepanovski.
  * report subprocess exit code when execution fails.  Thanks
    Marius Gedminas.
- additional changes from version 1.8.0:
  * new multi-dimensional configuration support.  Many thanks to
    Alexander Schepanovski for the complete PR with docs. And to
    Mike Bayer and others for testing and feedback.
  * fix issue148: remove "__PYVENV_LAUNCHER__" from os.environ when
    starting subprocesses. Thanks Steven Myint.
  * fix issue152: set VIRTUAL_ENV when running test commands,
    thanks Florian Ludwig.
  * better report if we can't get version_info from an interpreter
    executable. Thanks Floris Bruynooghe.
- update project URL
- refresh tox-disable-env-tests.patch
* Mon Aug 25 2014 aj@suse.com
- Update to version 1.7.2:
  * fix issue150: parse {posargs} more like we used to do it pre
    1.7.0.
  * fix issue59: add a config variable skip-missing-interpreters as
    well as command line option --skip-missing-interpreters
  * fix issue164: better traceback info in case of failing test commands
  * support optional env variable substitution.
  * limit python hashseed to 1024 on Windows to prevent possible
    memory errors.
* Thu Jul  3 2014 speilicke@suse.com
- Update to version 1.7.1:
  - fix issue162: don't list python 2.5 as compatibiliy/supported
  - fix issue158 and fix issue155: windows/virtualenv properly works now:
    call virtualenv through "python -m virtualenv" with the same
    interpreter which invoked tox.  Thanks Chris Withers, Ionel Maries Cristian.
- Add tox-disable-env-tests.patch: Disable tests that need network-access
  and that depend on /usr/bin/tox (which is only added via u-a in %%post)
- Remove tox-disable-network-accessing-tests.patch: Obsoleted by the above patch
- Implement update-alternatives to allow parallel installation with python3-tox
* Thu Sep 19 2013 speilicke@suse.com
- (Build)Require python-argparse on SLE
* Thu Sep  5 2013 speilicke@suse.com
- Update to version 1.6.0:
  + fix issue119: {envsitepackagesdir} is now correctly computed and has
    a better test to prevent regression.
  + fix issue116: make 1.6 introduced behaviour of changing to a
    per-env HOME directory during install activities dependent
    on "--set-home" for now.  Should re-establish the old behaviour
    when no option is given.
  + fix issue118: correctly have two tests use realpath(). Thanks Barry
    Warsaw.
  + fix test runs on environments without a home directory
    (in this case we use toxinidir as the homedir)
  + fix issue117: python2.5 fix: don't use ``--insecure`` option because
    its very existence depends on presence of "ssl".  If you
    want to support python2.5/pip1.3.1 based test environments you need
    to install ssl and/or use PIP_INSECURE=1 through ``setenv``. section.
  + fix issue102: change to {toxinidir} when installing dependencies.
    this allows to use relative path like in "-rrequirements.txt".
- Changes from version 1.6.0:
  + fix issue35: add new EXPERIMENTAL "install_command" testenv-option to
    configure the installation command with options for dep/pkg install.
    Thanks Carl Meyer for the PR and docs.
  + fix issue91: python2.5 support by vendoring the virtualenv-1.9.1
    script and forcing pip<1.4. Also the default [py25] environment
    modifies the default installer_command (new config option)
    to use pip without the "--pre" option which was introduced
    with pip-1.4 and is now required if you want to install non-stable
    releases.  (tox defaults to install with "--pre" everywhere).
  + during installation of dependencies HOME is now set to a pseudo
    location ({envtmpdir}/pseudo-home).  If an index url was specified
    a .pydistutils.cfg file will be written with an index_url setting
    so that packages defining ``setup_requires`` dependencies will not
    silently use your HOME-directory settings or https://pypi.python.org.
  + fix issue1: empty setup files are properly detected, thanks Anthon van
    der Neuth
  + remove toxbootstrap.py for now because it is broken.
  + fix issue109 and fix issue111: multiple "-e" options are now combined
    (previously the last one would win). Thanks Anthon van der Neut.
  + add --result-json option to write out detailed per-venv information
    into a json report file to be used by upstream tools.
  + add new config options ``usedevelop`` and ``skipsdist`` as well as a
    command line option ``--develop`` to install the package-under-test in develop mode.
    thanks Monty Tailor for the PR.
  + always unset PYTHONDONTWRITEBYTE because newer setuptools doesn't like it
  + if a HOMEDIR cannot be determined, use the toxinidir.
  + refactor interpreter information detection to live in new
    tox/interpreters.py file, tests in tests/test_interpreters.py.
- Add tox-disable-network-accessing-tests.patch: Disable tests that insist on
  downloading dependencies over network
- Run testsuite
* Tue Jun 25 2013 dmueller@suse.com
- update to 1.5.0:
  - fix issue104: use setuptools by default, instead of distribute,
  now that setuptools has distribute merged.
  - make sure test commands are searched first in the virtualenv
  - re-fix issue2 - add whitelist_externals to be used in ``[testenv*]``
  sections, allowing to avoid warnings for commands such as ``make``,
  used from the commands value.
  - fix issue97 - allow substitutions to reference from other sections
  (thanks Krisztian Fekete)
  - fix issue92 - fix {envsitepackagesdir} to actually work again
  - show (test) command that is being executed, thanks
  Lukasz Balcerzak
  - re-license tox to MIT license
  - depend on virtualenv-1.9.1
  - rename README.txt to README.rst to make bitbucket happier
* Mon Jun 17 2013 speilicke@suse.com
- Only require argparse on SLE, it's part of Python-2.7
* Sun Apr 21 2013 toms@opensuse.org
- Update to version 1.4.3:
  See http://testrun.org/tox/latest//changelog.html for more details
- SPEC file: Added bcond with test to prepare testing. Doesn't work
  yet, but can be improved
* Thu Jul 26 2012 saschpe@suse.de
- Update to version 1.4.2:
  + fix some tests which fail if /tmp is a symlink to some other place
  + "python setup.py test" now runs tox tests via tox :)
    also added an example on how to do it for your project.
- Changes from version 1.4.1:
  + fix issue41 better quoting on windows - you can now use "<" and ">" in
    deps specifications, thanks Chris Withers for reporting
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 1.4:
  + fix issue26 - no warnings on absolute or relative specified paths for commands
  + fix issue33 - commentchars are ignored in key-value settings allowing
    for specifying commands like: python -c "import sys ; print sys"
    which would formerly raise irritating errors because the ";"
    was considered a comment
  + tweak and improve reporting
  + refactor reporting and virtualenv manipulation
    to be more accessible from 3rd party tools
  + support value substitution from other sections
    with the {[section]key} syntax
  + fix issue29 - correctly point to pytest explanation
    for importing modules fully qualified
  + fix issue32 - use --system-site-packages and don't pass --no-site-packages
  + add python3.3 to the default env list, so early adopters can test
  + drop python2.4 support (you can still have your tests run on
    python-2.4, just tox itself requires 2.5 or higher.
* Tue Feb 21 2012 saschpe@suse.de
- Don't use nose, but custom script to run testsuite
* Mon Feb 20 2012 saschpe@gmx.de
- Initial version
